#
# spec file for package alttab
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alttab
Version:        1.7.1
Release:        2.3
Summary:        Task Switcher
License:        GPL-3.0-only
URL:            https://github.com/sagb/alttab
Source:         https://github.com/sagb/alttab/archive/v%{version}.tar.gz
BuildRequires:  /usr/bin/ronn
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libXft-devel
BuildRequires:  libXpm-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXrender-devel
BuildRequires:  libpng-devel
BuildRequires:  uthash-devel

%description
alttab is a X11 window switcher designed for minimalistic window managers or standalone X11 session.

%prep
%setup -q

%build
# workaround for GCC10 build failure
export CFLAGS="%(echo %{optflags}) -fcommon"
export CXXFLAGS="$CFLAGS"

./bootstrap.sh
%configure
%make_build

%install
%make_install

%files
%doc %{_datadir}/doc/alttab/
%{_bindir}/alttab
%{_mandir}/man1/alttab.1%{?ext_man}

%changelog
* Fri Aug 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire /usr/bin/ronn instead of rubygem(ronn): there are
  alternatives around and the build does not care wich one is used.
* Tue May  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * Show username in bottom line: -b 2.
  * Option -ns to ignore _NET_WM_STATE_SKIP_TASKBAR.
  * Better man page.
  * Fix an "empty window name" check,
  * Fix typographical errors.
* Thu Mar  9 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.0:
  * Option -e to keep the switcher.
  * Document usage on mobile devices.
  * Configurable bordercolor.
  * Build scripts for OpenBSD.
  * Fix xpm icon bug.
  * Feature: kill window by pressing 'k'.
  * Feature: line at the bottom of tile.
  * Show windows on scratchpad only: -d 4
  * Disable icons: -s 4
  * Prevent segfault on zero size tile or icon.
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.1:
  * Vertical layout.
  * Extra border around the alttab window.
* Mon Mar 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Fix major memory leak when huge icons are not used.
  * Debug by SIGUSR1.
  * Add test suite: running in headless X server.
  * Add github CI pipeline.
  * Bspwm documentation.
  * Fix possible strncpy overflows.
* Fri Jul 24 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.5.0:
  * Use xpm icons and pixmap directories.
  * Use XDG_DATA_DIRS.
  * Add extra keys: next/prev, cancel.
  * Optimize main event loop.
  * Fix numerous memleaks and overflows.
  * Satisfy gcc 10 requirements.
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon to allow the package to build with GCC10
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Jun 18 2019 mvetter@suse.com
- Use rubygem(ronn) instead of hardcoded ruby version
* Thu May 23 2019 mvetter@suse.com
- Initial package in version 1.4.0 for openSUSE
